==> common-3.3.1-sources.jar: com/microsoft/identity/common/internal/platform/AsymmetricKeyAccessor.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.platform;

import com.microsoft.identity.common.exception.ClientException;

import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PublicKey;
import java.security.UnrecoverableEntryException;

/**
 * An accessor for asymmetric keys.  The main differnce between this an a KeyAccessor is that
 * this accessor allows for retrieval of the public key of the key pair.
 */
public interface AsymmetricKeyAccessor extends KeyAccessor {
    /**
     * Return a public key in the specified format.
     * @param format a format according to {@link IDevicePopManager.PublicKeyFormat}.
     * @return the encoded public key.
     * @throws ClientException if there is a failure while retrieving it.
     */
    String getPublicKey(IDevicePopManager.PublicKeyFormat format) throws ClientException;

    /**
     * @return the {@link java.security.PublicKey} portion of this key pair.
     * @throws UnrecoverableEntryException if the entry is not recoverable from the keystore.
     * @throws NoSuchAlgorithmException if the public key being retrieved corresponds to an algorithm that is not supported.
     * @throws KeyStoreException if the keystore is not initialized.
     */
    public PublicKey getPublicKey() throws UnrecoverableEntryException, NoSuchAlgorithmException, KeyStoreException;
}

==> common-3.6.4-sources.jar: com/microsoft/identity/common/internal/platform/AsymmetricKeyAccessor.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.platform;

import com.microsoft.identity.common.exception.ClientException;

import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.PublicKey;
import java.security.UnrecoverableEntryException;

/**
 * An accessor for asymmetric keys.  The main differnce between this an a KeyAccessor is that
 * this accessor allows for retrieval of the public key of the key pair.
 */
public interface AsymmetricKeyAccessor extends IManagedKeyAccessor<KeyStore.PrivateKeyEntry> {
    /**
     * Return a public key in the specified format.
     * @param format a format according to {@link IDevicePopManager.PublicKeyFormat}.
     * @return the encoded public key.
     * @throws ClientException if there is a failure while retrieving it.
     */
    String getPublicKey(IDevicePopManager.PublicKeyFormat format) throws ClientException;

    /**
     * @return the {@link java.security.PublicKey} portion of this key pair.
     * @throws UnrecoverableEntryException if the entry is not recoverable from the keystore.
     * @throws NoSuchAlgorithmException if the public key being retrieved corresponds to an algorithm that is not supported.
     * @throws KeyStoreException if the keystore is not initialized.
     */
    public PublicKey getPublicKey() throws UnrecoverableEntryException, NoSuchAlgorithmException, KeyStoreException;
}
